// -*- c++ -*-

// $Id: infodialog.h,v 1.6 2003/01/12 05:03:20 nhasan Exp $

#ifndef IMAGEINFODIALOG_H
#define IMAGEINFODIALOG_H

#include <kdialogbase.h>

class Canvas;
class QLabel;

class imageInfoDialog : public KDialogBase
{
    Q_OBJECT

public:

    imageInfoDialog(Canvas *c, QWidget* parent= 0, const char* name= 0);

private:
    QLabel* colourDepth;
    QLabel* coloursUsed;
    QLabel* width;
    QLabel* height;
};

#endif // IMAGEINFODIALOG_H
